@@ -16,6 +16,30 @@ FIRST_DAY_WEEK = 0
 
 supports_alpha = False
 
+def googleToDays(s):
+  d = []
+  if 'SU' in s:
+    d.append(6)
+  if 'MO' in s:
+    d.append(0)
+  if 'TU' in s:
+    d.append(1)
+  if 'WE' in s:
+    d.append(2)
+  if 'TH' in s:
+    d.append(3)
+  if 'FR' in s:
+    d.append(4)
+  if 'SA' in s:
+    d.append(5)
+  if 'SU' in s:
+    d.append(6)
+
+  if len(d)==0:
+    d = [0,1,2,3,4,5,6]
+
+  return d
+
 def addMonth(date, n=1):
     # add n+1 months to date then subtract 1 day
     # to get eom, last day of target month
@@ -198,7 +222,7 @@ class IPPlugin(hildondesktop.HomeItem):
 
 			where = where + ')'
 
-			dbcur.execute('SELECT  start, end, description,uuid,repeat,repeatvalue,frequency,until FROM events  '+where + '  AND description<>"DELETED" ORDER by start')       
+			dbcur.execute('SELECT  start, end, description,uuid,repeat,repeatvalue,frequency,until,byday FROM events  '+where + '  AND description<>"DELETED" ORDER by start')       
 			events = dbcur.fetchall()
 			if len(events)==0:
 			  text = text + '\nNo events'
@@ -206,6 +230,7 @@ class IPPlugin(hildondesktop.HomeItem):
 			  repeat = event[4]
 			  repeatvalue = int(event[5])
 			  frequency = event[6]
+			  byday = event[8]
 			  until = datetime.datetime.strptime(event[7],'%Y-%m-%d %H:%M')
 			  start_datetime = datetime.datetime.strptime(event[0],'%Y-%m-%d %H:%M')
 			  end_datetime = datetime.datetime.strptime(event[1],'%Y-%m-%d %H:%M')
@@ -216,14 +241,14 @@ class IPPlugin(hildondesktop.HomeItem):
 			      diff = datetime.timedelta(days=repeatvalue)
 			      d = start_datetime
 			      while (d.date() <= until.date()) and (d.date() <= self.view_datetime.date()):
-			        if d.date() == self.view_datetime.date():
+			        if (d.date() == self.view_datetime.date()) and (self.view_datetime.weekday() in googleToDays(byday)):
 			  			  text = text +'\n'+ d.strftime(WEEK_VIEW_FORMAT)+':'+event[2]
 			        d = d+diff
 			    elif frequency=="Week(s)":
 			      diff = datetime.timedelta(days=repeatvalue*7)
 			      d = start_datetime
 			      while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
-			        if d.strftime("%W")==self.view_datetime.strftime("%W"):
+			        if (d.strftime("%W")==self.view_datetime.strftime("%W")) and (self.view_datetime.weekday() in googleToDays(byday)):
 			          text = text +'\n'+ d.strftime(WEEK_VIEW_FORMAT)+':'+event[2]
 			        d = d+diff
 			    elif frequency=="Month(s)":
@@ -235,7 +260,7 @@ class IPPlugin(hildondesktop.HomeItem):
 			    elif frequency=="Year(s)":
 			      d = start_datetime
 			      while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
-			        if (d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%W")==self.view_datetime.strftime("%W")):
+			        if ((d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%W")==self.view_datetime.strftime("%W"))) and (self.view_datetime.weekday() in googleToDays(byday)):
 			          text = text + '\n'+d.strftime(WEEK_VIEW_FORMAT)+':'+event[2]
 			        d = addMonth(d,repeatvalue*12) 
 
@@ -250,7 +275,7 @@ class IPPlugin(hildondesktop.HomeItem):
 			where = where + ' OR (start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'" AND repeat=1 AND frequency="Year(s)" AND until>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'" AND strftime("%d",start)='+str(self.view_datetime.day)+' AND strftime("%m",start)='+str(self.view_datetime.month)+' AND (('+str((self.view_datetime.year))+'-((strftime("%Y",start)))) % (repeatvalue))==0 ) '
 			where = where + ')'
 
-			dbcur.execute('SELECT  start, end, description,uuid,repeat,repeatvalue,frequency,until FROM events  '+where + '  AND description<>"DELETED" ORDER by start')       
+			dbcur.execute('SELECT  start, end, description,uuid,repeat,repeatvalue,frequency,until,byday FROM events  '+where + '  AND description<>"DELETED" ORDER by start')       
 			events = dbcur.fetchall()
 			if len(events)!=0:
 			  text = text + "\n\n<b>Tomorrow "+self.view_datetime.strftime('%x')+"</b>"
@@ -258,6 +283,7 @@ class IPPlugin(hildondesktop.HomeItem):
 			  repeat = event[4]
 			  repeatvalue = int(event[5])
 			  frequency = event[6]
+			  byday = event[8]
 			  until = datetime.datetime.strptime(event[7],'%Y-%m-%d %H:%M')
 			  start_datetime = datetime.datetime.strptime(event[0],'%Y-%m-%d %H:%M')
 			  end_datetime = datetime.datetime.strptime(event[1],'%Y-%m-%d %H:%M')
@@ -268,26 +294,26 @@ class IPPlugin(hildondesktop.HomeItem):
 			      diff = datetime.timedelta(days=repeatvalue)
 			      d = start_datetime
 			      while (d.date() <= until.date()) and (d.date() <= self.view_datetime.date()):
-			        if d.date() == self.view_datetime.date():
+			        if (d.date() == self.view_datetime.date()) and (self.view_datetime.weekday() in googleToDays(byday)):
 			  			  text = text +'\n'+ d.strftime(WEEK_VIEW_FORMAT)+':'+event[2]
 			        d = d+diff
 			    elif frequency=="Week(s)":
 			      diff = datetime.timedelta(days=repeatvalue*7)
 			      d = start_datetime
 			      while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
-			        if d.strftime("%W")==self.view_datetime.strftime("%W"):
+			        if (d.strftime("%W")==self.view_datetime.strftime("%W")) and (self.view_datetime.weekday() in googleToDays(byday)):
 			          text = text +'\n'+ d.strftime(WEEK_VIEW_FORMAT)+':'+event[2]
 			        d = d+diff
 			    elif frequency=="Month(s)":
 			      d = start_datetime
 			      while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
-			        if d.strftime("%W")==self.view_datetime.strftime("%W"):
+			        if (d.strftime("%W")==self.view_datetime.strftime("%W")) and (self.view_datetime.weekday() in googleToDays(byday)):
 			          text = text + '\n'+d.strftime(WEEK_VIEW_FORMAT)+':'+event[2]
 			        d = addMonth(d,repeatvalue) 
 			    elif frequency=="Year(s)":
 			      d = start_datetime
 			      while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
-			        if (d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%W")==self.view_datetime.strftime("%W")):
+			        if ((d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%W")==self.view_datetime.strftime("%W"))) and (self.view_datetime.weekday() in googleToDays(byday)):
 			          text = text + '\n'+d.strftime(WEEK_VIEW_FORMAT)+':'+event[2]
 			        d = addMonth(d,repeatvalue*12) 
 
